Package: cuRe
Type: Package
Title: Parametric Cure Model Estimation
Version: 1.1.1
Date: 2023-07-03
Authors@R: c(person(given = "Lasse Hjort Jakobsen", role = c("aut", "cre"), email = "hjort9230@hotmail.com"), 
             person(given = "Mark Clements", role = c("cph")),
             person(given = "Rasmus Kuhr Jensen", role = c("ctb")),
             person(given = "Lars Klingen Gjærde", role = c("ctb")))
Maintainer: Lasse Hjort Jakobsen <hjort9230@hotmail.com>
Description: Contains functions for estimating generalized parametric mixture and non-mixture cure models <doi:10.1016/j.cmpb.2022.107125>, loss of lifetime, mean residual lifetime, and crude event probabilities.
URL: https://github.com/LasseHjort/cuRe
BugReports: https://github.com/LasseHjort/cuRe/issues
License: GPL (>= 2)
Encoding: UTF-8
Depends: R (>= 3.5.0), survival, rstpm2, date
Imports: numDeriv, statmod, relsurv, reshape2
LazyData: Yes
RoxygenNote: 7.2.3
NeedsCompilation: no
Packaged: 2023-07-03 05:29:52 UTC; hjort
Author: Lasse Hjort Jakobsen [aut, cre],
  Mark Clements [cph],
  Rasmus Kuhr Jensen [ctb],
  Lars Klingen Gjærde [ctb]
Repository: CRAN
Date/Publication: 2023-07-03 06:40:02 UTC
Built: R 4.6.0; ; 2026-04-30 23:20:21 UTC; unix
