# Generated by roxygen2: do not edit by hand

S3method(AIC,cm)
S3method(AIC,gfcm)
S3method(BIC,cm)
S3method(BIC,gfcm)
S3method(lrtest,cuRe)
S3method(plot,crude)
S3method(plot,cuRe)
S3method(plot,le)
S3method(plot,lts)
S3method(predict,cb)
S3method(predict,cbc)
S3method(predict,cm)
S3method(predict,gfcm)
S3method(print,cm)
S3method(print,gfcm)
S3method(print,summary.cm)
S3method(print,summary.gfcm)
S3method(summary,cm)
S3method(summary,gfcm)
export(GenFlexCureModel)
export(calc.Crude)
export(calc.Crude.quantile)
export(calc.LL)
export(calc.LL.quantile)
export(calc.cure.quantile)
export(cb)
export(cbc)
export(fit.cure.model)
export(general.haz)
export(lrtest)
export(lts)
import(date)
import(relsurv)
import(rstpm2)
import(survival)
importFrom(graphics,abline)
importFrom(numDeriv,hessian)
importFrom(numDeriv,jacobian)
importFrom(reshape2,melt)
importFrom(splines,splineDesign)
importFrom(statmod,gauss.quad)
importFrom(stats,.checkMFClasses)
importFrom(stats,as.formula)
importFrom(stats,delete.response)
importFrom(stats,dnorm)
importFrom(stats,lm)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,na.pass)
importFrom(stats,optim)
importFrom(stats,pnorm)
importFrom(stats,printCoefmat)
importFrom(stats,pt)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,rnorm)
importFrom(stats,smooth.spline)
importFrom(stats,terms)
importFrom(stats,uniroot)
importFrom(utils,tail)
